@@ -1,11 +1,7 @@
 package Net::Douban::DBSubject;
-
-BEGIN {
-    $Net::Douban::DBSubject::VERSION = '1.07_2';
-}
+our $VERSION = '1.04';
 
 use Moose;
-use MooseX::StrictConstructor;
 extends 'Net::Douban::Entry';
 
 sub BUILD {
