@@ -1,12 +1,7 @@
 package Net::Douban::Doumail;
-
-BEGIN {
-    $Net::Douban::Doumail::VERSION = '1.07_2';
-}
+our $VERSION = '1.04';
 
 use Moose;
-use MooseX::StrictConstructor;
-use Net::Douban::Atom;
 use Carp qw/carp croak/;
 with 'Net::Douban::Roles::More';
 
@@ -15,17 +10,6 @@ has 'doumailID' => (
     isa => 'Str',
 );
 
-has 'doumail_url' => (
-    is      => 'rw',
-    isa     => 'Url',
-    lazy    => 1,
-    default => sub { shift->base_url . '/doumail' },
-);
-
-before qw/inbox unread outbox get_doumail/ => sub {
-    croak "oauth needed" unless $_[0]->has_oauth;
-};
-
 sub inbox {
     my ($self, %args) = @_;
     return Net::Douban::Atom->new(
@@ -46,37 +30,33 @@ sub outbox {
 
 sub get_doumail {
     my ($self, %args) = @_;
-    $args{mailID} ||= $self->mailID;
-    croak "mailID needed" unless defined $args{mailID};
+    $args{doumailID} ||= $self->doumailID;
     return Net::Douban::Atom->new(
-        $self->get($self->doumail_url . "/$args{mailID}", %args));
+        $self->get($self->doumail_url . "/$args{doumailID}", %args));
 }
 
 sub post_doumail {
     my ($self, %args) = @_;
     croak "post xml needed!" unless $args{xml};
-    return $self->post($self->doumail_url . 's', xml => $args{xml});
+    return $self->post($self->doumail_url . 's', $args{xml},);
 }
 
 sub delete_doumail {
     my ($self, %args) = @_;
-    $args{mailID} ||= $self->mailID;
-    croak "mailID needed" unless defined $args{mailID};
-    return $self->delete($self->doumail_url . "/$args{mailID}");
+    $args{doumailID} ||= $self->doumailID;
+    return $self->delete($self->doumail_url . "/$args{doumailID}",);
 }
 
 sub mark_read {
     my ($self, %args) = @_;
-    $args{mailID} ||= $self->mailID;
-    croak "mailID needed"   unless defined $args{mailID};
-    croak "put xml needed!" unless $args{xml};
-    return $self->put($self->doumail_url . "/$args{mailID}",
-        xml => $args{xml});
+    $args{doumailID} ||= $self->doumailID;
+    croak "post xml needed!" unless $args{xml};
+    return $self->put($self->doumail_url . "/$args{doumailID}", $args{xml},);
 }
 
 sub delete {
     my ($self, %args) = @_;
-    croak "delete xml needed!" unless $args{xml};
+    croak "post xml needed!" unless $args{xml};
     return $self->delete($self->doumail_url, $args{xml});
 }
 
@@ -97,12 +77,12 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 VERSION
 
-version 1.07_2
+version 1.04
 
 =head1 SYNOPSIS
 
 	use Net::Douban::Doumail;
-	my $mail= Net::Douban::Doumail->new(
+	my $user = Net::Douban::Doumail->new(
         ...
 	);
 
@@ -136,7 +116,7 @@ Interface to douban.com API  mail section
 
 =head1 SEE ALSO
 
-L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> L<http://douban.com/service/apidoc/reference/douamil>
+L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> L<http//douban.com/service/apidoc>
 
 =head1 AUTHOR
 
