@@ -1,11 +1,7 @@
 package Net::Douban::Entry;
-
-BEGIN {
-    $Net::Douban::Entry::VERSION = '1.07_2';
-}
+our $VERSION = '1.04';
 
 use Moose;
-use MooseX::StrictConstructor;
 use Net::Douban::DBSubject;
 use Carp qw/carp croak/;
 
@@ -98,24 +94,24 @@ sub subject {
     return $k;
 }
 
-#sub DESTROY { }
-#our $AUTOLOAD;
-#
-#sub AUTOLOAD {
-#
-#    #	my $self = shift;
-#    #	my $class = ref $self ? ref $self : $self;
-#    (my $name = $AUTOLOAD) =~ s/.*:://g;
-#    return if $name eq 'DESTROY';
-#    my $sub = <<SUB;
-#	sub $name {
-#		my \$self =  shift;
-#		return \$self->get($name);
-#	}
-#SUB
-#    eval($sub);    ## the same as *$name = $sub;
-#    goto &$name;
-#}
+sub DESTROY { }
+our $AUTOLOAD;
+
+sub AUTOLOAD {
+
+    #	my $self = shift;
+    #	my $class = ref $self ? ref $self : $self;
+    (my $name = $AUTOLOAD) =~ s/.*:://g;
+    return if $name eq 'DESTROY';
+    my $sub = <<SUB;
+	sub $name {
+		my \$self =  shift;
+		return \$self->get($name);
+	}
+SUB
+    eval($sub);    ## the same as *$name = $sub;
+    goto &$name;
+}
 1;
 
 __END__
@@ -130,7 +126,7 @@ Net::Douban::Entry
 
 =head1 VERSION
 
-version 1.07_2
+version 1.04
 
 =head1 SYNOPSIS
 	
@@ -156,6 +152,10 @@ Many functions not listed here are documented in L<XML::Atom::Entry>
 
 see L<Net::Douban::Atom>
 
+=item AUTOLOAD
+
+see L<Net::Douban::Atom>
+
 =item content
 
 	$entry->content();
