@@ -1,13 +1,8 @@
 package Net::Douban::Event;
-
-BEGIN {
-    $Net::Douban::Event::VERSION = '1.07_2';
-}
+our $VERSION = '1.04';
 
 use Moose;
-use MooseX::StrictConstructor;
 use Carp qw/carp croak/;
-use Net::Douban::Atom;
 with 'Net::Douban::Roles::More';
 
 has 'eventID' => (
@@ -15,17 +10,9 @@ has 'eventID' => (
     isa => 'Str',
 );
 
-has 'event_url' => (
-    is      => 'rw',
-    isa     => 'Url',
-    lazy    => 1,
-    default => sub { shift->base_url . '/event' },
-);
-
 sub get_event {
     my ($self, %args) = @_;
     $args{eventID} ||= $self->eventID;
-    croak "eventID need!" unless exists $args{eventID};
     return Net::Douban::Atom->new(
         $self->get($self->event_url . "/$args{eventID}"));
 }
@@ -33,7 +20,6 @@ sub get_event {
 sub get_event_wishers {
     my ($self, %args) = @_;
     $args{eventID} ||= $self->eventID;
-    croak "eventID need!" unless exists $args{eventID};
     return Net::Douban::Atom->new(
         $self->get($self->event_url . "/$args{eventID}/wishers"));
 }
@@ -41,7 +27,6 @@ sub get_event_wishers {
 sub get_event_participants {
     my ($self, %args) = @_;
     $args{eventID} ||= $self->eventID;
-    croak "eventID need!" unless exists $args{eventID};
     return Net::Douban::Atom->new(
         $self->get($self->event_url . "/$args{eventID}/participants"));
 }
@@ -67,7 +52,7 @@ sub get_user_wish {
         $self->get($self->user_url . "/$uid/events/wish", %args));
 }
 
-sub get_user_events {
+sub get_user_event {
     my ($self, %args) = @_;
     my $uid = delete $args{userID} or croak "userID needed";
     return Net::Douban::Atom->new(
@@ -90,28 +75,26 @@ sub search {
 sub post_event {
     my ($self, %args) = @_;
     croak "post xml needed!" unless exists $args{xml};
-    return $self->post($self->event_url . "s", xml => $args{xml});
+    return $self->post($self->event_url . "s", $args{xml});
 }
 
 sub put_event {
     my ($self, %args) = @_;
     $args{eventID} ||= $self->eventID;
-    croak "eventID need!"    unless exists $args{eventID};
     croak "post xml needed!" unless exists $args{xml};
-    return $self->put($self->event_url . "/$args{eventID}",
-        xml => $args{xml});
+    return $self->put($self->event_url . "/$args{eventID}", $args{xml});
 }
 
 sub join_event {
     my ($self, %args) = @_;
     $args{eventID} ||= $self->eventID;
-    return $self->post($self->event_url . "/$args{eventID}/participants");
+    return $self->post($self->event_url . "$args{eventID}/participants");
 }
 
 sub wish_event {
     my ($self, %args) = @_;
     $args{eventID} ||= $self->eventID;
-    return $self->post($self->event_url . "/$args{eventID}/wishers");
+    return $self->post($self->event_url . "$args{eventID}/wishers");
 }
 
 sub delete_event {
@@ -119,7 +102,7 @@ sub delete_event {
     croak "post xml needed" unless exists $args{xml};
     $args{eventID} ||= $self->eventID;
     return $self->post($self->event_url . "/$args{eventID}/delete",
-        xml => $args{xml});
+        $args{xml});
 }
 
 sub leave_event {
@@ -137,88 +120,3 @@ sub quit_event {
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-Net::Douban::Event
-
-=head1 VERSION
-
-version 1.07_2
-
-=head1 SYNOPSIS
-
-	use Net::Douban::Event;
-	my $event = Net::Douban::Event->new(
-		apikey => '....',
-        # or
-        oauth => $consumer,
-	);
-
-	$atom = $event->get_event;
-	$atom = $event->get_event_wishers;
-    $atom = $event->search(q => 'douban', locationID => 'all', start_index => 5, max_results => 10);
-
-=head1 DESCRIPTION
-
-Interface to douban.com API Event section
-
-=head1 METHODS
-
-Most of the get methods return a Net::Douban::Atom object which can be use to get data conveniently
-
-=over
-
-=item B<get_event>
-
-=item B<get_event_wishers>
-
-=item B<get_event_participants>
-
-=item B<get_user_participants>
-
-=item B<get_user_wish>
-
-=item B<get_user_event>
-
-=item B<get_city_events>
-
-=item B<search>
-
-=item B<post_event>
-
-=item B<join_event>
-
-=item B<put_event>
-
-=item B<wish_event>
-
-=item B<delete_event>
-
-=item B<leave_event>
-
-=item B<quit_event>
-
-=back
-
-=head1 SEE ALSO
-
-L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> B<http://www.douban.com/service/apidoc/reference/event>
-
-=head1 AUTHOR
-
-woosley.xu<redicaps@gmail.com>
-
-=head1 COPYRIGHT
-	
-Copyright (C) 2010 by Woosley.Xu
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
-
-=cut
