@@ -1,14 +1,10 @@
 package Net::Douban::OAuth;
-
-BEGIN {
-    $Net::Douban::OAuth::VERSION = '1.07_2';
-}
-
+our $VERSION = '1.04';
 use Moose;
 use Carp qw/carp croak/;
 use Net::Douban::OAuth::Consumer;
 
-has 'consumer_key' => (
+has 'comsumer_key' => (
     is  => 'ro',
     isa => 'Str',
 );
@@ -20,46 +16,24 @@ has 'consumer_secret' => (
 
 has 'consumer' => (
     is      => 'rw',
-    lazy    => 1,
     default => \&_build_consumer,
 );
 
 has 'site' => (
     is      => 'rw',
-    isa     => 'Maybe[Str]',
     default => 'http://www.douban.com',
 );
 
 has 'request_token_path' => (
     is      => 'rw',
-    isa     => 'Maybe[Str]',
     default => '/service/auth/request_token',
 );
 
-has 'authorize_path' => (
-    is      => 'rw',
-    isa     => 'Maybe[Str]',
-    default => '/service/auth/authorize',
-);
-
 has 'access_token_path' => (
     is      => 'rw',
-    isa     => 'Maybe[Str]',
     default => '/service/auth/access_token',
 );
 
-has 'authorize_url' => (
-    is       => 'rw',
-    isa      => 'Maybe[Str]',
-    init_arg => undef,
-);
-
-has 'callback_url' => (
-    is        => 'rw',
-    isa       => 'Maybe[Str]',
-    predicate => 'has_callback',
-);
-
 sub _build_consumer {
 
     my $self = shift;
@@ -73,33 +47,39 @@ sub _build_consumer {
     );
 }
 
-sub BUILD {
-    my ($self, $arg) = @_;
-    my %args = %{$arg};
+around 'BUILDARGS' => sub {
+    my $orig = shift;
+    my $self = shift;
+    my %args = @_;
 
     if (   $args{access_token}
         || $args{access_token_secret}
         || $args{request_token}
         || $args{request_token_secret})
     {
-        $args{request_token_path} ||= $self->request_token_path;
-        $args{access_token_path}  ||= $self->access_token_path;
-        $args{site}               ||= $self->site;
         my $consumer = Net::Douban::OAuth::Consumer->new(%args);
-        $self->consumer($consumer);
+        return $self->$orig(@_, consumer => $consumer);
     }
-}
+    return $self->$orig(@_);
+};
+
+####不能new?
+#sub new_authorized {
+#    my ($self, %args) = @_;
+#    $self->BUILD(%args);
+#    $args{consumer_key} = delete $args{apikey};
+#    $args{consumer_secret} = delete $args{private_key};
+#    my $consumer = Net::Douban::OAuth::Consumer->new(
+#        authorized => 1,
+#        %args,
+#    );
+#    $self->consumer($consumer);
+#    $self->authorized(1);
+#    return $self;
+#}
 
 sub request_token {
-    my $self = shift;
-    $self->consumer->get_request_token;
-    my $url =
-        $self->site
-      . $self->authorize_path
-      . '?oauth_token='
-      . $self->consumer->request_token;
-    $url .= '&oauth_callback=' . $self->callback_url if $self->has_callback;
-    $self->authorize_url($url);
+    shift->consumer->get_request_token;
 }
 
 sub access_token {
@@ -107,6 +87,7 @@ sub access_token {
 }
 
 sub get {
+
     my $self = shift;
     croak "unauthorized" unless $self->consumer->authorized;
     (my $request_url = shift) or croak "url needed";
@@ -118,6 +99,7 @@ sub get {
 }
 
 sub post {
+
     my $self = shift;
     croak "unauthorized" unless $self->consumer->authorized;
     my ($request_url, $content, $header) = @_;
@@ -139,6 +121,7 @@ sub post {
 }
 
 sub put {
+
     my $self = shift;
     croak "unauthorized" unless $self->consumer->authorized;
     my ($request_url, $content, $header) = @_;
@@ -154,6 +137,7 @@ sub put {
 }
 
 sub delete {
+
     my ($self, $request_url) = @_;
     croak "unauthorized" unless $self->consumer->authorized;
     croak "Url needed"   unless $request_url;
@@ -166,7 +150,6 @@ sub delete {
 
 sub validate {
 
-    # to do
 }
 
 1;
@@ -179,24 +162,25 @@ __END__
 
 =head1 NAME
 
-    Net::Douban::OAuth - OAuth object for Net::Douban
+    Net::Douban::OAuth
 
 =head1 VERSION
 
-version 1.07_2
+version 1.04
 
 =head1 SYNOPSIS
     
     my $oauth = Net::Douban::OAuth->new(
         consumer_key => ,
         consumer_secret => ,
+        site => ,
+        request_token_path => ,
+        access_token_path =>, 
     );
 
-    $oauth->callback_url($url);
     $oauth->request_token;
-    print $oauth->authorize_url; # paste this url to your user
-    $oauth->access_token; # now this object is authorized 
-    $agent = Net::Douban->new(oauth => $oauth);
+    $oauth->access_token;
+
 
 =head1 DESCRIPTION
     
@@ -229,7 +213,7 @@ get access_token into $oauth->consumer
 
 =head1 SEE ALSO
     
-L<Net::Douban> L<Moose> L<Net::OAuth> L<http://douban.com/service/apidoc/auth>
+L<Net::Douban> L<Moose> L<Net::OAuth> L<http://douban.com/service/apidoc>
 
 =head1 AUTHOR
 
