@@ -1,5 +1,5 @@
 package Net::Douban::OAuth::Consumer;
-our $VERSION = '1.07_2';
+our $VERSION = '1.03';
 use Net::OAuth;
 use HTTP::Request::Common;
 use HTTP::Request;
@@ -223,11 +223,11 @@ __END__
 
 =head1 NAME
 
-Net::Douban::OAuth::Consumer - Base consumer object for Net::Douban::OAuth
+Net::Douban::OAuth::Consumer
 
 =head1 VERSION
 
-version 1.06_1
+version 1.04
 
 =head1 SYNOPSIS
     
