@@ -1,12 +1,7 @@
 package Net::Douban::Tag;
-
-BEGIN {
-    $Net::Douban::Tag::VERSION = '1.07_2';
-}
+our $VERSION = '1.04';
 
 use Moose;
-use MooseX::StrictConstructor;
-use Net::Douban::Atom;
 use Carp qw/carp croak/;
 with 'Net::Douban::Roles::More';
 
