@@ -1,14 +1,10 @@
 package Net::Douban::User;
-
-BEGIN {
-    $Net::Douban::User::VERSION = '1.07_2';
-}
+our $VERSION = '1.04';
 
 use Moose;
-with 'Net::Douban::Roles::More';
 use Net::Douban::Atom;
 use Carp qw/carp croak/;
-use MooseX::StrictConstructor;
+with 'Net::Douban::Roles::More';
 
 has 'userID' => (is => 'rw', isa => 'Str',);
 
@@ -60,7 +56,7 @@ Net::Douban::User
 
 =head1 VERSION
 
-version 1.07_2
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -76,7 +72,6 @@ version 1.07_2
 	$atom = $user->get_user;
 	$atom = $user->get_friends;
 	$atom = $user->get_contacts;
-    $atom = $user->search(q => 'douban', start_index => 5, max_results => 10);
 
 =head1 DESCRIPTION
 
@@ -84,8 +79,6 @@ Interface to douban.com API User section
 
 =head1 METHODS
 
-Those methods return a Net::Douban::Atom object which can be use to get data conveniently
-
 =over
 
 =item B<get_user>
@@ -102,7 +95,7 @@ Those methods return a Net::Douban::Atom object which can be use to get data con
 
 =head1 SEE ALSO
 
-L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> B<http://www.douban.com/service/apidoc/reference/user>
+L<Net::Douban> L<Net::Douban::Atom> L<Moose> L<XML::Atom> B<douban.com/service/apidoc>
 
 =head1 AUTHOR
 
